@@ -7,7 +7,8 @@ from rest_framework.decorators import action
 from rest_framework.response import Response
 from rest_framework_simplejwt.views import TokenViewBase
 
-from drf_auth_service.authentication.serializers import LoginSerializer, EBSTokenRefreshSerializer, ReturnRegisterSerializer, \
+from drf_auth_service.authentication.serializers import LoginSerializer, EBSTokenRefreshSerializer, \
+    ReturnRegisterSerializer, \
     ReturnAccessTokenSerializer
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
