@@ -18,8 +18,9 @@ SSO_SETTINGS_NAMESPACE = "DRF_AUTH_SERVICE"
 
 EMAIL_HOST = getattr(django_settings, 'EMAIL_HOST')
 EMAIL_PORT = getattr(django_settings, 'EMAIL_PORT')
-EMAIL_USERNAME = getattr(django_settings, 'EMAIL_USERNAME')
-EMAIL_PASSWORD = getattr(django_settings, 'EMAIL_USERNAME')
+EMAIL_USERNAME = getattr(django_settings, 'EMAIL_HOST_USER')
+EMAIL_PASSWORD = getattr(django_settings, 'EMAIL_HOST_PASSWORD')
+EMAIL_USE_TLS = getattr(django_settings, 'EMAIL_USE_TLS')
 
 
 class ObjDict(dict):
@@ -66,10 +67,10 @@ default_sso_settings = {
     "EMAIL_PORT": EMAIL_PORT,
     "EMAIL_USERNAME": EMAIL_USERNAME,
     "EMAIL_PASSWORD": EMAIL_PASSWORD,
+    "EMAIL_USE_TLS": EMAIL_USE_TLS,
     "HTML_RESET_PASSWORD_SUBJECT": "Reset password receive",
     "HTML_DEFAULT_FROM_EMAIL": "info@ebs.com",
     "HTML_CONFIRMATION_SUBJECT": "Confirmation link",
-    "EMAIL_USE_TLS": True,
     "HTML_EMAIL_RESET_TEMPLATE": "example/path/to/template",
     "HTML_EMAIL_CONFIRM_TEMPLATE": "example/path/to/template",
     "SERIALIZERS": ObjDict({
